# eric7.Plugins.VcsPlugins.vcsSubversion.SvnNewProjectOptionsDialog

Module implementing the Subversion Options Dialog for a new project from the repository.

### Global Attributes

None

### Classes

SvnNewProjectOptionsDialog | Class implementing the Options Dialog for a new project from the repository.

### Functions

None

## SvnNewProjectOptionsDialog

Class implementing the Options Dialog for a new project from the repository.

### Derived from

QDialog, Ui_SvnNewProjectOptionsDialog

### Class Attributes

None

### Class Methods

None

### Methods

SvnNewProjectOptionsDialog | Constructor
getData | Public slot to retrieve the data entered into the dialog.
on_layoutCheckBox_toggled | Private slot to handle the change of the layout checkbox.
on_protocolCombo_activated | Private slot to switch the status of the directory selection button.
on_vcsProjectDirPicker_textChanged | Private slot to handle a change of the project directory.
on_vcsUrlPicker_pickerButtonClicked | Private slot to display a repository browser dialog.
on_vcsUrlPicker_textChanged | Private slot to handle changes of the URL.

### Static Methods

None

#### SvnNewProjectOptionsDialog (Constructor)

SvnNewProjectOptionsDialog(vcs, parent=None)

Constructor

vcs (Subversion)
  reference to the version control object
parent (QWidget)
  parent widget

#### SvnNewProjectOptionsDialog.getData

getData()

Public slot to retrieve the data entered into the dialog.

Return:
  tuple containing the (project directory and a dictionary containing the data entered.

Return Type:
  tuple of (str, dict)

#### SvnNewProjectOptionsDialog.on_layoutCheckBox_toggled

on_layoutCheckBox_toggled(checked)

Private slot to handle the change of the layout checkbox.

checked (bool)
  flag indicating the state of the checkbox

#### SvnNewProjectOptionsDialog.on_protocolCombo_activated

on_protocolCombo_activated(index)

Private slot to switch the status of the directory selection button.

index (int)
  index of the selected entry

#### SvnNewProjectOptionsDialog.on_vcsProjectDirPicker_textChanged

on_vcsProjectDirPicker_textChanged(txt)

Private slot to handle a change of the project directory.

txt (str)
  name of the project directory

#### SvnNewProjectOptionsDialog.on_vcsUrlPicker_pickerButtonClicked

on_vcsUrlPicker_pickerButtonClicked()

Private slot to display a repository browser dialog.

#### SvnNewProjectOptionsDialog.on_vcsUrlPicker_textChanged

on_vcsUrlPicker_textChanged(txt)

Private slot to handle changes of the URL.

txt (str)
  current text of the line edit

Up